==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/admin/config-more.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");
include("../include/header.inc.php");

$VAR["Heading"] = _NEWCONT;
$out = new KWL_Html;
$VAR["Content"] = $out->form_start("admin/submit.php","config")
. $out->table_start("100%",'',1,0,3) ."
<tr>
	<td>". _MENU_BLOCK ."</td>
	<td>". $out->select("menu_blockw",array("l" => _BLOCK_LEFT, "r" => _BLOCK_RIGHT),$CONF['menu_blockw']) ."
	</td>
</tr>
<tr>
   <td>"._SHOW_CONTACT."</td>
   <td>". $out->radio("CONTACT",array(_NOTUSE,_USE),$CONF['CONTACT']) ."</td>
</tr>
<tr>
   <td>"._SHOW_PTIME."</td>
   <td>". $out->radio("CHECK_TIME",array(_NOTUSE,_USE),$CONF['CHECK_TIME']) ."</td>
</tr>
<tr>
   <td>"._FILE_CACHE."</td>
   <td>". $out->radio("File_Cache",array(_NOTUSE,_USE),$CONF['File_Cache']) ."</td>
</tr>
<tr>
   <td>"._SHOW_IP."</td>
   <td>". $out->radio("SHOW_IP",array(_NOTUSE,_USE),$CONF['SHOW_IP']) ."</td>
</tr>
<tr>
   <td>"._ENABLE_DAY."</td>
   <td>". $out->radio("DAYOFWEEK",array(_NOTUSE,_USE),$CONF['DAYOFWEEK']) ."</td>
</tr>
<tr>
   <td>"._ANTI_SPAM."</td>
   <td>". $out->radio("SPAM_CHECK",array(_NOTUSE,_USE,_CHANGE),$CONF['SPAM_CHECK']) ."</td>
</tr>
<tr>
   <td>"._ANTI_SPAM2."</td>
   <td>". $out->radio("BLOCK_IP",array(_NOTUSE,_USE),$CONF['BLOCK_IP']) ."</td>
</tr>
<tr>
   <td>"._ANTI_IP."</td>
   <td>". $out->radio("SPAM_IP",array(_NOTUSE,_USE),$CONF['SPAM_IP']) ."</td>
</tr>
<tr>
   <td>"._FORM_WRAP."</td>
   <td>". $out->radio("FORM_WRAP",array("Off","Hard","Virtual"),$CONF['FORM_WRAP']) ."</td>
</tr>
<tr>
   <td>"._QP_ENCODE."</td>
   <td>". $out->radio("QP_Encode",array(_NOTUSE,_USE),$CONF['QP_Encode']) ."</td>
</tr>
<tr>
   <td>"._FEATURE_TITLE."</td>
   <td>". $out->input_form("TEXT","feature",htmlspecialchars($CONF['feature']),KWL_FormSize(12),128) ."</td>
</tr>
<tr>
   <td>Navigation bar delimiter</td>
   <td>". $out->input_form("TEXT","nchar",trim($CONF['nchar']),4,4) ."</td>
</tr>
<tr>
   <td>Dot Character</td>
   <td>". $out->input_form("TEXT","dotchar",htmlspecialchars($CONF['dotchar']),KWL_FormSize(15),50) ."<br />
   default: ". htmlspecialchars("<strong><big>&#183;</big></strong>") ."
   </td>
</tr>
<tr>
   <td>"._RSS_POPWINDOW."</td>
   <td>". $out->radio("rss_popwin",array(_NOTUSE,_USE),$CONF['rss_popwin']) ."</td>
</tr>
<tr>
	<td colspan='2'>"
	. $out->input_form("hidden","what","config-more")
	. $out->input_form("submit","mode",_SAVE_CHANGE) ."</td>
</tr>". $out->table_end() . $out->form_end();

KWL_DrawMain($VAR);
include("../include/footer.inc.php");
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/admin/config-more.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");
include("../include/header.inc.php");

$VAR["Heading"] = _NEWCONT;
$out = new KWL_Html;
if (empty($CONF['wrap_width'])) $CONF['wrap_width'] = 100;
$VAR["Content"] = $out->form_start("admin/submit.php","config")
. $out->table_start("100%",'',1,0,3) ."
<tr>
	<td>". _MENU_BLOCK ."</td>
	<td>". $out->select("menu_blockw",array("l" => _BLOCK_LEFT, "r" => _BLOCK_RIGHT),$CONF['menu_blockw']) ."
	</td>
</tr>
<tr>
   <td>"._SHOW_CONTACT."</td>
   <td>". $out->radio("CONTACT",array(_NOTUSE,_USE),$CONF['CONTACT']) ."</td>
</tr>
<tr>
   <td>"._SHOW_PTIME."</td>
   <td>". $out->radio("CHECK_TIME",array(_NOTUSE,_USE),$CONF['CHECK_TIME']) ."</td>
</tr>
<tr>
   <td>"._FILE_CACHE."</td>
   <td>". $out->radio("File_Cache",array(_NOTUSE,_USE),$CONF['File_Cache']) ."</td>
</tr>
<tr>
   <td>"._SHOW_IP."</td>
   <td>". $out->radio("SHOW_IP",array(_NOTUSE,_USE),$CONF['SHOW_IP']) ."</td>
</tr>
<tr>
   <td>"._ENABLE_DAY."</td>
   <td>". $out->radio("DAYOFWEEK",array(_NOTUSE,_USE),$CONF['DAYOFWEEK']) ."</td>
</tr>
<tr>
   <td>"._ANTI_SPAM."</td>
   <td>". $out->radio("SPAM_CHECK",array(_NOTUSE,_USE,_CHANGE),$CONF['SPAM_CHECK']) ."</td>
</tr>
<tr>
   <td>"._ANTI_SPAM2."</td>
   <td>". $out->radio("BLOCK_IP",array(_NOTUSE,_USE),$CONF['BLOCK_IP']) ."</td>
</tr>
<tr>
   <td>"._ANTI_IP."</td>
   <td>". $out->radio("SPAM_IP",array(_NOTUSE,_USE),$CONF['SPAM_IP']) ."</td>
</tr>
<tr>
   <td>"._FORM_WRAP."</td>
   <td>". $out->radio("FORM_WRAP",array("Off","Hard","Virtual"),$CONF['FORM_WRAP']) ."</td>
</tr>
<tr>
   <td>"._QP_ENCODE."</td>
   <td>". $out->radio("QP_Encode",array(_NOTUSE,_USE),$CONF['QP_Encode']) ."</td>
</tr>
<tr>
   <td>"._FEATURE_TITLE."</td>
   <td>". $out->input_form("TEXT","feature",htmlspecialchars($CONF['feature']),KWL_FormSize(12),128) ."</td>
</tr>
<tr>
   <td>Navigation Bar Delimiter</td>
   <td>". $out->input_form("TEXT","nchar",trim($CONF['nchar']),4,4) ."</td>
</tr>
<tr>
   <td>Dot Character</td>
   <td>". $out->input_form("TEXT","dotchar",htmlspecialchars($CONF['dotchar']),KWL_FormSize(15),50) ."<br />
   default: ". htmlspecialchars("<strong><big>&#183;</big></strong>") ."
   </td>
</tr>
<tr>
   <td>"._RSS_POPWINDOW."</td>
   <td>". $out->radio("rss_popwin",array(_NOTUSE,_USE),$CONF['rss_popwin']) ."</td>
</tr>
<tr>
   <td>HTML Contents Wordwrap</td>
   <td>". $out->radio("wordwrap",array(_NOTUSE,_USE),$CONF['wordwrap']) ."<br />
   Wordwrap Width: ". $out->input_form('text','wrap_width',$CONF['wrap_width'],10) ."</td>
</tr>
<tr>
	<td colspan='2'>"
	. $out->input_form("hidden","what","config-more")
	. $out->input_form("submit","mode",_SAVE_CHANGE) ."</td>
</tr>". $out->table_end() . $out->form_end();

KWL_DrawMain($VAR);
include("../include/footer.inc.php");
?>
